@@ -7,7 +7,8 @@ use Scalar::Util 'blessed';
 use Number::Phone::Country qw(noexport);
 use Number::Phone::StubCountry;
 
-our $VERSION = '3.0014';
+# MUST be in format N.NNNN, see https://github.com/DrHyde/perl-modules-Number-Phone/issues/58
+our $VERSION = '3.4006';
 
 my $NOSTUBS = 0;
 sub import {
@@ -24,7 +25,7 @@ my @is_methods = qw(
     is_geographic is_fixed_line is_mobile is_pager
     is_tollfree is_specialrate is_adult is_network_service is_personal
     is_corporate is_government is_international
-    is_ipphone is_isdn
+    is_ipphone is_isdn is_drama
 );
 
 foreach my $method (
@@ -46,7 +47,6 @@ sub type {
 
 sub country {
     my $class = blessed(shift);
-    return unless $class;
     (my @two_letter_codes) = $class =~ /\b([A-Z]{2})\b/g;
     return $two_letter_codes[-1];
 }
@@ -84,6 +84,27 @@ sub dial_to {
 
 sub intra_country_dial_to { die("don't know how\n"); }
 
+sub format_using {
+    my $self   = shift;
+    my $format = shift;
+
+    return $self->format() if($format eq 'E123');
+
+    eval "use Number::Phone::Formatter::$format";
+    die("Couldn't load format '$format': $@\n") if($@);
+    return "Number::Phone::Formatter::$format"->format($self->format(), $self);
+}
+
+sub format_for_country {
+  my $self = shift;
+  my $country_code = shift || '';
+  $country_code = Number::Phone::Country::country_code($country_code)
+    if $country_code && $country_code =~ /[a-z]/i;
+  $country_code =~ s/^\+//;
+  return $self->format_using('National') if $country_code eq $self->country_code();
+  return $self->format_using('NationallyPreferredIntl');
+}
+
 1;
 
 =head1 NAME
@@ -122,9 +143,21 @@ Early versions of this module allowed what are now object methods
 to also be called as class methods or even as functions. This was a
 bad design decision. Use of those calling conventions was deprecated
 in version 2.0, released in January 2012, and started to emit
-warnings.
+warnings. All code to support those calling conventions has now been removed.
 
-All code to support those calling conventions has now been removed.
+Until 2017 we ued KOS for the country code for Kosovo, that has now changed to
+XK. See L<Number::Phone::Country>.
+
+From version 3.4000 to 3.4003 inclusive we accepted any old garbage after
++383 as being valid, as the Kosovo numbering plan had not been published.
+Now that that has been published, we use libphonenumber data, and validate
+against it.
+
+The prefix codes in 3.4003 and earlier were managed by hand and so got out
+of date. After that release they are mostly derived from libphonenumber.
+libphonenumber's data includes carrier selection codes when they are
+mandatory for dialling so those are now included. This sometimes means that
+some random carrier has been arbitrarily priveleged over others.
 
 =head1 COMPATIBILTY WITH libphonenumber
 
@@ -135,8 +168,8 @@ If you pass in a country code for which
 no supporting module is available, the constructor will try to use a 'stub'
 class under Number::Phone::StubCountry::* that uses data automatically
 extracted from Google's libphonenumber project.  libphonenumber doesn't
-have enough data to support all the features of Number::Phone, and this
-is an experimental feature.  If you want to disable this, then pass 'nostubs'
+have enough data to support all the features of Number::Phone.
+If you want to disable this, then pass 'nostubs'
 when you use the module:
 
     use Number::Phone qw(nostubs);
@@ -164,8 +197,6 @@ sub _new_args {
       $number = join('', grep { defined } ($country, $number));
     }
 
-    die("Need to specify a number for ".__PACKAGE__."->new()\n")
-        unless($number);
     die("Number::Phone->new(): too many params\n")
         if(exists($_[2]));
     $number =~ s/[^+0-9]//g;
@@ -323,6 +354,11 @@ various "Country Direct"-a-likes.  See also the C<country()> method.
 The number is some kind of network service such as the operator, directory
 enquiries, emergency services etc
 
+=item is_drama
+
+The number is for use in fiction, such as TV and Radio drama programmes.
+It will not be allocated for use in real life.
+
 =back
 
 =head2 OTHER NUMBER METADATA METHODS
@@ -401,12 +437,37 @@ C<[qw(valid allocated geographic)]>.
 
 =item format
 
-Return a sanely formatted version of the number, complete with IDD code, eg
-for the UK number (0208) 771-2924 it would return +44 20 8771 2924.
+Return a sanely formatted E.123-compliant version of the number, complete with
+IDD code, eg for the UK number (0208) 771-2924 it would return +44 20 8771
+2924.
 
 The superclass implementation returns undef, which is nonsense, so you
 should always implement this.
 
+=item format_using
+
+If you want something different from E.123, then pass this the name of a
+L<formatter|Number::Phone::Formatters> to use.
+
+For example, if you want to get "just the digits, ma'am", use the
+L<Raw|Number::Phone::Formatter::Raw> formatter thus:
+
+  Number::Phone->new('+44 20 8771 2924')->format_using('Raw');
+
+which will return:
+
+  2087712924
+
+It is a fatal error to specify a non-existent formatter.
+
+=item format_for_country
+
+Given a country code (either two-letter ISO or numeric prefix), return the
+number formatted either nationally-formatted, if the number is in the same
+country, or as a nationally-preferred international number if not. Internally
+this uses the National and NationallyPreferredIntl formatters. Beware of the
+potential performance hit!
+
 =item country
 
 The two letter ISO country code for the country in which the call will
@@ -444,8 +505,6 @@ The superclass implementation returns undef.
 
 =item dial_to
 
-EXPERIMENTAL METHOD
-
 Takes another Number::Phone object as its only argument and returns a
 string showing how to dial from the number represented by the invocant
 to that represented by the argument.
